rule win_bumblebee_auto {

    meta:
        author = "Felix Bilstein - yara-signator at cocacoding dot com"
        date = "2023-12-06"
        version = "1"
        description = "Detects win.bumblebee."
        info = "autogenerated rule brought to you by yara-signator"
        tool = "yara-signator v0.6.0"
        signator_config = "callsandjumps;datarefs;binvalue"
        malpedia_reference = "https://malpedia.caad.fkie.fraunhofer.de/details/win.bumblebee"
        malpedia_rule_date = "20231130"
        malpedia_hash = "fc8a0e9f343f6d6ded9e7df1a64dac0cc68d7351"
        malpedia_version = "20230808"
        malpedia_license = "CC BY-SA 4.0"
        malpedia_sharing = "TLP:WHITE"

    /* DISCLAIMER
     * The strings used in this rule have been automatically selected from the
     * disassembly of memory dumps and unpacked files, using YARA-Signator.
     * The code and documentation is published here:
     * https://github.com/fxb-cocacoding/yara-signator
     * As Malpedia is used as data source, please note that for a given
     * number of families, only single samples are documented.
     * This likely impacts the degree of generalization these rules will offer.
     * Take the described generation method also into consideration when you
     * apply the rules in your use cases and assign them confidence levels.
     */


    strings:
        $sequence_0 = { 0fb7570e 6623d1 740d 0fbe470d b90d000000 2bc8 }
            // n = 6, score = 2800
            //   0fb7570e             | dec                 eax
            //   6623d1               | test                eax, eax
            //   740d                 | je                  0x139
            //   0fbe470d             | cmove               eax, ecx
            //   b90d000000           | cmp                 dword ptr [eax + ebx], 0
            //   2bc8                 | je                  0x7b

        $sequence_1 = { 0f44c1 833c1800 7475 837c180400 746e 8b1418 488b05???????? }
            // n = 7, score = 2800
            //   0f44c1               | mov                 edx, dword ptr [esp + 0x48]
            //   833c1800             | dec                 eax
            //   7475                 | lea                 ecx, [esp + 0x38]
            //   837c180400           | dec                 eax
            //   746e                 | mov                 dword ptr [esp + 0x20], ecx
            //   8b1418               | js                  0x146
            //   488b05????????       |                     

        $sequence_2 = { 0f88cc000000 4863533c 488b05???????? 4803d6 4885c0 0f84b5000000 488d4c2430 }
            // n = 7, score = 2800
            //   0f88cc000000         | js                  0xd2
            //   4863533c             | dec                 eax
            //   488b05????????       |                     
            //   4803d6               | arpl                word ptr [ebx + 0x3c], dx
            //   4885c0               | dec                 eax
            //   0f84b5000000         | add                 edx, esi
            //   488d4c2430           | dec                 eax

        $sequence_3 = { 0f880c010000 488b7580 4885f6 0f84ff000000 488b05???????? 4885c0 0f84ef000000 }
            // n = 7, score = 2800
            //   0f880c010000         | mov                 dword ptr [esp + 0x28], 0x8000000
            //   488b7580             | dec                 esp
            //   4885f6               | lea                 eax, [ebp - 0x30]
            //   0f84ff000000         | dec                 eax
            //   488b05????????       |                     
            //   4885c0               | mov                 dword ptr [ebp - 0x28], esi
            //   0f84ef000000         | lea                 eax, [esi + 0x40]

        $sequence_4 = { 0f8895000000 8b7b28 b8c0000000 4803fe ba64860000 66395304 8d4810 }
            // n = 7, score = 2800
            //   0f8895000000         | js                  0xd2
            //   8b7b28               | dec                 eax
            //   b8c0000000           | arpl                word ptr [ebx + 0x3c], dx
            //   4803fe               | dec                 eax
            //   ba64860000           | add                 edx, esi
            //   66395304             | dec                 eax
            //   8d4810               | test                eax, eax

        $sequence_5 = { 0fbec0 8d59e8 8d1c58 ffc2 }
            // n = 4, score = 2800
            //   0fbec0               | dec                 eax
            //   8d59e8               | arpl                word ptr [ebx + 0x3c], dx
            //   8d1c58               | dec                 eax
            //   ffc2                 | add                 edx, esi

        $sequence_6 = { 0f57c0 c744242800000008 4c8d45d0 488975d8 8d4640 488975e0 }
            // n = 6, score = 2800
            //   0f57c0               | add                 edi, esi
            //   c744242800000008     | js                  0x146
            //   4c8d45d0             | dec                 eax
            //   488975d8             | test                eax, eax
            //   8d4640               | je                  0x139
            //   488975e0             | dec                 eax

        $sequence_7 = { 0f8840010000 488b05???????? 4885c0 0f8430010000 488b542448 488d4c2438 48894c2420 }
            // n = 7, score = 2800
            //   0f8840010000         | mov                 eax, 0xc0
            //   488b05????????       |                     
            //   4885c0               | dec                 eax
            //   0f8430010000         | add                 edi, esi
            //   488b542448           | mov                 edx, 0x8664
            //   488d4c2438           | cmp                 word ptr [ebx + 4], dx
            //   48894c2420           | js                  0x9b

    condition:
        7 of them and filesize < 4825088
}